@@ -70,7 +70,7 @@ class ClientAPIAuthenticatedListView(ListView):
     paginator_class = ClientAPIPagination
     client_method = None
     client_method_result_key = 'results'
-    extra_kwargs = []
+    api_filters = []
     page_base_url = ''
     page_title = ''
 
@@ -105,17 +105,18 @@ class ClientAPIAuthenticatedListView(ListView):
                 'message': str(e)
             })
 
-    def get_extra_params(self, request):
-        default_kwargs_list = ['search']
-        default_kwargs_list.extend(self.extra_kwargs)
-        extra_params = {}
-        for param in default_kwargs_list:
+    def get_api_params(self, request):
+        default_api_filters = ['search']
+        default_api_filters.extend(self.api_filters)
+        api_filters = {}
+        for param in default_api_filters:
             param_value = request.GET.get(param, '')
             if param_value:
-                extra_params[param] = param_value
-        return extra_params
+                api_filters[param] = param_value
+        return api_filters
 
     def get_context_data(self, **kwargs):
+        filter_params = kwargs.pop('filter_params', False)
         paginate_by = self.get_paginate_by()
         if paginate_by:
             paginator, page, queryset, is_paginated = self._paginate_queryset(self.client_method,
@@ -139,6 +140,7 @@ class ClientAPIAuthenticatedListView(ListView):
         context.update({
             'search': self.request.GET.get('search', ''),
             'search_url': search_url,
+            'filter_params': filter_params,
             'page_base_url': self.get_page_base_url(),
             'range_pagination': [x for x in range(20, 220, 20)],
             'paginate_by': paginate_by,
@@ -152,7 +154,9 @@ class ClientAPIAuthenticatedListView(ListView):
         return context
 
     def get(self, request, *args, **kwargs):
-        params = self.get_extra_params(request)
+        params = self.get_api_params(request)
+        if params:
+            params['filter_params'] = True
 
         context = self.get_context_data(**params)
         self.object_list = context['object_list']
@@ -160,20 +164,6 @@ class ClientAPIAuthenticatedListView(ListView):
         if params:
             context.update(params)
 
-        if request.is_ajax():
-            paginator = context['paginator']
-            more = False
-            if paginator.num_pages > 1:
-                more = True
-
-            results = [{'id': instance.code, 'text': instance.brand.upper()} for instance in self.object_list]
-            data = {
-                "results": results,
-                "pagination": {
-                    "more": more
-                }
-            }
-            return HttpResponse(json.dumps(data))
         return self.render_to_response(context)
 
 
